@@ -22,7 +22,7 @@
 #pod =for :this This is C<Perl::PrereqScanner::Scanner::Hint> module documentation. Read this if you are going to hack or
 #pod extend C<Manifest::Write>.
 #pod
-#pod =for :those If you want to specify implicit prerequisites directly in your Perl code, read the L<user manual|Perl::PrereqScanner::Scanner::Hint::Manual>.
+#pod =for :those If you want to specify implicit prerequisites directly in Perl code, read the L<user manual|Perl::PrereqScanner::Scanner::Hint::Manual>.
 #pod General topics like getting source, building, installing, bug reporting and some others are covered
 #pod in the F<README>.
 #pod
@@ -57,8 +57,8 @@ use namespace::autoclean;
 use version 0.77;
 use warnings::register;
 
-# ABSTRACT: Plugin for C<Perl::PrereqScanner> looking for C<# REQUIRE:> comments
-our $VERSION = 'v0.1.0_01'; # TRIAL VERSION
+# ABSTRACT: Plugin for C<Perl::PrereqScanner> looking for C<## REQUIRE:> comments
+our $VERSION = 'v0.1.1'; # VERSION
 
 use Module::Runtime qw{ is_module_name };
 use Try::Tiny;
@@ -179,12 +179,11 @@ __END__
 
 =head1 NAME
 
-Perl::PrereqScanner::Scanner::Hint - Plugin for C<Perl::PrereqScanner> looking for C<# REQUIRE:> comments
+Perl::PrereqScanner::Scanner::Hint - Plugin for C<Perl::PrereqScanner> looking for C<## REQUIRE:> comments
 
 =head1 VERSION
 
-Version v0.1.0_01, released on 2016-12-19 23:53 UTC.
-This is a B<trial release>.
+Version v0.1.1, released on 2016-12-28 20:18 UTC.
 
 =head1 WHAT?
 
@@ -194,7 +193,7 @@ tool. C<Scanner::Hint> looks for C<# REQUIRE: I<ModuleName> I<VersionRange>> com
 This is C<Perl::PrereqScanner::Scanner::Hint> module documentation. Read this if you are going to hack or
 extend C<Manifest::Write>.
 
-If you want to specify implicit prerequisites directly in your Perl code, read the L<user manual|Perl::PrereqScanner::Scanner::Hint::Manual>.
+If you want to specify implicit prerequisites directly in Perl code, read the L<user manual|Perl::PrereqScanner::Scanner::Hint::Manual>.
 General topics like getting source, building, installing, bug reporting and some others are covered
 in the F<README>.
 
